@@ -321,6 +321,11 @@ class Client(metaclass=SingletonClass):
         """Returns the radio browser instance"""
         return self._radio_manager
 
+    @property
+    def dispatch_manager(self) -> DispatchManager:
+        """Returns the dispatch manager"""
+        return self._dispatch_manager
+
     @property
     def player_config_manager(self) -> PlayerConfigController:
         """Returns the player config manager"""
